# ion-channel-python-sdk

This is a Python SDK for the Ion Channel Application Programming Interface

Note: This SDK package is still in an alpha development stage - use cautiously

Installation: pip install pyonic

